@@ -9,6 +9,7 @@ u"""
     :license: MIT, see License for more details.
 """
 
+from __future__ import with_statement
 from __future__ import absolute_import
 import os
 import subprocess
@@ -71,9 +72,8 @@ class Document(BaseLaTeXContainer):
 
     def generate_tex(self):
         u"""Generates a .tex file."""
-        newf = open(self.filename + u'.tex', u'w')
-        self.dump(newf)
-        newf.close()
+        with open(self.filename + u'.tex', u'w') as newf:
+            self.dump(newf)
     generate_tex.func_annotations = {}
 
     def generate_pdf(self, clean=True):
