@@ -18,7 +18,7 @@ from pylatex.command import Command
 
 class VectorName(Command):
     def __init__(self, name):
-        super(VectorName, self).__init__(u'mathbf', argument=name)
+        super(VectorName, self).__init__(u'mathbf', arguments=name)
     __init__.func_annotations = {}
 
 
